//reference: 	http://www.learnopengl.com/#!Lighting/Basic-Lighting
//				http://www.learnopengl.com/#!Lighting/Materials
#version 330 core

struct Material {
	vec3 ambient;
	vec3 diffuse;
	vec3 specular;
	float shininess;
};

struct Light {
    vec3 position;
    vec3 ambient;
    vec3 diffuse;
    vec3 specular;
};

in vec3 Normal;
in vec3 FragPos;

out vec4 color;

uniform vec3 viewPos;
uniform mat4 view;
uniform Material material;
uniform Light light;
void main()
{
	//ambient lighting
	vec3 ambient = light.ambient * material.ambient;
	vec3 viewPos2 = vec3(view[3].x, view[3].y, view[3].z);
	//diffuse lighting
	//using unit vectors for diffuse lighting
	vec3 norm = normalize(Normal);
	vec3 lightDir = normalize(light.position - FragPos);
	//vec3 lightDir = normalize(-light.position);// - FragPos);
	float diff = max(dot(norm, lightDir), 0.0);
	vec3 diffuse = light.diffuse * (diff * material.diffuse);
	
	//specular lighting
	vec3 viewDir = normalize(viewPos2 - FragPos);
	//vec3 viewDir = normalize(- FragPos);
    vec3 reflectDir = reflect(-lightDir, norm);  
    float spec = pow(max(dot(viewDir, reflectDir), 0.0), material.shininess);	//32 = shininess of highlight ; the larger the number the smaller the spot
    vec3 specular = light.specular * (spec * material.specular);  
	
	
	vec3 result = (ambient + diffuse + specular);
	color = vec4(result, 1.0f);
}